#ifndef kedusimpleentrydlg_included
#define kedusimpleentrydlg_included

#include <qobject.h>

#include "kedusimpleentrydlgForm.h"

class KEduSimpleEntryDlg : public KEduSimpleEntryDlgForm
{
    Q_OBJECT

 public:





};

#endif // kedusimpleentrydlg_included
